==> jc-1.4.0.tar.gz: java/awt/event/MouseAdapter.h <==
// public abstract class java.awt.event.MouseAdapter

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_event_MouseAdapter_H_
#define _JC_java_awt_event_MouseAdapter_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_MouseAdapter$sub_refs	_jc_java_awt_event_MouseAdapter$sub_refs;
typedef struct _jc_java_awt_event_MouseAdapter$sub_nonrefs	_jc_java_awt_event_MouseAdapter$sub_nonrefs;
typedef struct _jc_java_awt_event_MouseAdapter$refs	_jc_java_awt_event_MouseAdapter$refs;
typedef struct _jc_java_awt_event_MouseAdapter$nonrefs	_jc_java_awt_event_MouseAdapter$nonrefs;
typedef struct _jc_java_awt_event_MouseAdapter$object	_jc_java_awt_event_MouseAdapter$object;

typedef const struct _jc_java_awt_event_MouseAdapter$vmethods	_jc_java_awt_event_MouseAdapter$vmethods;
typedef const struct _jc_java_awt_event_MouseAdapter$vtable	_jc_java_awt_event_MouseAdapter$vtable;
typedef const struct _jc_java_awt_event_MouseAdapter$vtype	_jc_java_awt_event_MouseAdapter$vtype;

// Constructors
extern void _jc_java_awt_event_MouseAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *);

// Virtual methods
extern void _jc_java_awt_event_MouseAdapter$method$mouseClicked$ce03b49f8488a52e(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_java_awt_event_MouseAdapter$method$mouseEntered$23499044fefa8766(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_java_awt_event_MouseAdapter$method$mouseExited$75603394b87c8a41(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_java_awt_event_MouseAdapter$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_java_awt_event_MouseAdapter$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_MouseAdapter$method_info$mouseClicked$ce03b49f8488a52e;
extern _jc_method _jc_java_awt_event_MouseAdapter$method_info$mouseEntered$23499044fefa8766;
extern _jc_method _jc_java_awt_event_MouseAdapter$method_info$mouseExited$75603394b87c8a41;
extern _jc_method _jc_java_awt_event_MouseAdapter$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_java_awt_event_MouseAdapter$method_info$mouseReleased$47ad6ad312932c8e;

// Virtual methods structure
struct _jc_java_awt_event_MouseAdapter$vmethods {
	void	(*mouseClicked$ce03b49f8488a52e)(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseEntered$23499044fefa8766)(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseExited$75603394b87c8a41)(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *);
};

// Vtable
struct _jc_java_awt_event_MouseAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
};

// Vtype
struct _jc_java_awt_event_MouseAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_event_MouseAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_MouseAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_MouseAdapter$refs {
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_MouseAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_MouseAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
};

// Object instance structure
struct _jc_java_awt_event_MouseAdapter$object {
	_jc_java_awt_event_MouseAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_MouseAdapter$vtype	*vtype;
	_jc_java_awt_event_MouseAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_MouseAdapter$vtype _jc_java_awt_event_MouseAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_MouseAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_MouseAdapter$class_object;

#endif	/* _JC_java_awt_event_MouseAdapter_H_ */

==> jc-1.4.6.tar.gz: java/awt/event/MouseAdapter.h <==
// public abstract class java.awt.event.MouseAdapter

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_event_MouseAdapter_H_
#define _JC_java_awt_event_MouseAdapter_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_MouseAdapter$sub_refs	_jc_java_awt_event_MouseAdapter$sub_refs;
typedef struct _jc_java_awt_event_MouseAdapter$sub_nonrefs	_jc_java_awt_event_MouseAdapter$sub_nonrefs;
typedef struct _jc_java_awt_event_MouseAdapter$refs	_jc_java_awt_event_MouseAdapter$refs;
typedef struct _jc_java_awt_event_MouseAdapter$nonrefs	_jc_java_awt_event_MouseAdapter$nonrefs;
typedef struct _jc_java_awt_event_MouseAdapter$object	_jc_java_awt_event_MouseAdapter$object;

typedef const struct _jc_java_awt_event_MouseAdapter$vmethods	_jc_java_awt_event_MouseAdapter$vmethods;
typedef const struct _jc_java_awt_event_MouseAdapter$vtable	_jc_java_awt_event_MouseAdapter$vtable;
typedef const struct _jc_java_awt_event_MouseAdapter$vtype	_jc_java_awt_event_MouseAdapter$vtype;

// Constructors
extern void _jc_java_awt_event_MouseAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_event_MouseAdapter$method$mouseClicked$ce03b49f8488a52e(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_MouseAdapter$method$mouseEntered$23499044fefa8766(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_MouseAdapter$method$mouseExited$75603394b87c8a41(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_MouseAdapter$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_MouseAdapter$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_MouseAdapter$method_info$mouseClicked$ce03b49f8488a52e;
extern _jc_method _jc_java_awt_event_MouseAdapter$method_info$mouseEntered$23499044fefa8766;
extern _jc_method _jc_java_awt_event_MouseAdapter$method_info$mouseExited$75603394b87c8a41;
extern _jc_method _jc_java_awt_event_MouseAdapter$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_java_awt_event_MouseAdapter$method_info$mouseReleased$47ad6ad312932c8e;

// Virtual methods structure
struct _jc_java_awt_event_MouseAdapter$vmethods {
	void	(*mouseClicked$ce03b49f8488a52e)(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseEntered$23499044fefa8766)(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseExited$75603394b87c8a41)(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_java_awt_event_MouseAdapter$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_MouseAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
};

// Vtype
struct _jc_java_awt_event_MouseAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_event_MouseAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_MouseAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_MouseAdapter$refs {
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_MouseAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_MouseAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
};

// Object instance structure
struct _jc_java_awt_event_MouseAdapter$object {
	_jc_java_awt_event_MouseAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_MouseAdapter$vtype	*vtype;
	_jc_java_awt_event_MouseAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_MouseAdapter$vtype _jc_java_awt_event_MouseAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_MouseAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_MouseAdapter$class_object;

#endif	/* _JC_java_awt_event_MouseAdapter_H_ */
